ReadPrimitive

Trait ReadPrimitive 

pub trait ReadPrimitive<T: PointerType> {
    // Required method
    fn read_primitive(&self, ptr: Pointer<T>) -> Result<T>;
}
Something that can read a primitive from a wasm memory location.

Required Methods

fn read_primitive(&self, ptr: Pointer<T>) -> Result<T>

Read a primitive from the given memory location ptr.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors